==> knative-model-6.0.0-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitLabBindingSpecFluentImpl<A extends GitLabBindingSpecFluent<A>> extends BaseFluent<A> implements GitLabBindingSpecFluent<A>{
  public GitLabBindingSpecFluentImpl() {
  }
  public GitLabBindingSpecFluentImpl(GitLabBindingSpec instance) {
    this.withAccessToken(instance.getAccessToken()); 
    this.withSubject(instance.getSubject()); 
  }
  private SecretValueFromSourceBuilder accessToken;
  private ReferenceBuilder subject;
  
  /**
   * This method has been deprecated, please use method buildAccessToken instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getAccessToken() {
    return this.accessToken!=null ?this.accessToken.build():null;
  }
  public SecretValueFromSource buildAccessToken() {
    return this.accessToken!=null ?this.accessToken.build():null;
  }
  public A withAccessToken(SecretValueFromSource accessToken) {
    _visitables.get("accessToken").remove(this.accessToken);
    if (accessToken!=null){ this.accessToken= new SecretValueFromSourceBuilder(accessToken); _visitables.get("accessToken").add(this.accessToken);} else { this.accessToken = null; _visitables.get("accessToken").remove(this.accessToken); } return (A) this;
  }
  public Boolean hasAccessToken() {
    return this.accessToken != null;
  }
  public GitLabBindingSpecFluent.AccessTokenNested<A> withNewAccessToken() {
    return new GitLabBindingSpecFluentImpl.AccessTokenNestedImpl();
  }
  public GitLabBindingSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(SecretValueFromSource item) {
    return new GitLabBindingSpecFluentImpl.AccessTokenNestedImpl(item);
  }
  public GitLabBindingSpecFluent.AccessTokenNested<A> editAccessToken() {
    return withNewAccessTokenLike(getAccessToken());
  }
  public GitLabBindingSpecFluent.AccessTokenNested<A> editOrNewAccessToken() {
    return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): new SecretValueFromSourceBuilder().build());
  }
  public GitLabBindingSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(SecretValueFromSource item) {
    return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSubject instead.
   * @return The buildable object.
   */
  @Deprecated
  public Reference getSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  public Reference buildSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  public A withSubject(Reference subject) {
    _visitables.get("subject").remove(this.subject);
    if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} else { this.subject = null; _visitables.get("subject").remove(this.subject); } return (A) this;
  }
  public Boolean hasSubject() {
    return this.subject != null;
  }
  public GitLabBindingSpecFluent.SubjectNested<A> withNewSubject() {
    return new GitLabBindingSpecFluentImpl.SubjectNestedImpl();
  }
  public GitLabBindingSpecFluent.SubjectNested<A> withNewSubjectLike(Reference item) {
    return new GitLabBindingSpecFluentImpl.SubjectNestedImpl(item);
  }
  public GitLabBindingSpecFluent.SubjectNested<A> editSubject() {
    return withNewSubjectLike(getSubject());
  }
  public GitLabBindingSpecFluent.SubjectNested<A> editOrNewSubject() {
    return withNewSubjectLike(getSubject() != null ? getSubject(): new ReferenceBuilder().build());
  }
  public GitLabBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(Reference item) {
    return withNewSubjectLike(getSubject() != null ? getSubject(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitLabBindingSpecFluentImpl that = (GitLabBindingSpecFluentImpl) o;
    if (accessToken != null ? !accessToken.equals(that.accessToken) :that.accessToken != null) return false;
    if (subject != null ? !subject.equals(that.subject) :that.subject != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accessToken,  subject,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accessToken != null) { sb.append("accessToken:"); sb.append(accessToken + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject); }
    sb.append("}");
    return sb.toString();
  }
  class AccessTokenNestedImpl<N> extends SecretValueFromSourceFluentImpl<GitLabBindingSpecFluent.AccessTokenNested<N>> implements GitLabBindingSpecFluent.AccessTokenNested<N>,Nested<N>{
    AccessTokenNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    AccessTokenNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) GitLabBindingSpecFluentImpl.this.withAccessToken(builder.build());
    }
    public N endAccessToken() {
      return and();
    }
    
  }
  class SubjectNestedImpl<N> extends ReferenceFluentImpl<GitLabBindingSpecFluent.SubjectNested<N>> implements GitLabBindingSpecFluent.SubjectNested<N>,Nested<N>{
    SubjectNestedImpl(Reference item) {
      this.builder = new ReferenceBuilder(this, item);
    }
    SubjectNestedImpl() {
      this.builder = new ReferenceBuilder(this);
    }
    ReferenceBuilder builder;
    public N and() {
      return (N) GitLabBindingSpecFluentImpl.this.withSubject(builder.build());
    }
    public N endSubject() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitLabBindingSpecFluentImpl<A extends GitLabBindingSpecFluent<A>> extends BaseFluent<A> implements GitLabBindingSpecFluent<A>{
  public GitLabBindingSpecFluentImpl() {
  }
  public GitLabBindingSpecFluentImpl(GitLabBindingSpec instance) {
    if (instance != null) {
      this.withAccessToken(instance.getAccessToken());
      this.withSubject(instance.getSubject());
    }
  }
  private SecretValueFromSourceBuilder accessToken;
  private ReferenceBuilder subject;
  
  /**
   * This method has been deprecated, please use method buildAccessToken instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getAccessToken() {
    return this.accessToken!=null ?this.accessToken.build():null;
  }
  public SecretValueFromSource buildAccessToken() {
    return this.accessToken!=null ?this.accessToken.build():null;
  }
  public A withAccessToken(SecretValueFromSource accessToken) {
    _visitables.get("accessToken").remove(this.accessToken);
    if (accessToken!=null){ this.accessToken= new SecretValueFromSourceBuilder(accessToken); _visitables.get("accessToken").add(this.accessToken);} else { this.accessToken = null; _visitables.get("accessToken").remove(this.accessToken); } return (A) this;
  }
  public Boolean hasAccessToken() {
    return this.accessToken != null;
  }
  public GitLabBindingSpecFluentImpl.AccessTokenNested<A> withNewAccessToken() {
    return new GitLabBindingSpecFluentImpl.AccessTokenNestedImpl();
  }
  public GitLabBindingSpecFluentImpl.AccessTokenNested<A> withNewAccessTokenLike(SecretValueFromSource item) {
    return new GitLabBindingSpecFluentImpl.AccessTokenNestedImpl(item);
  }
  public GitLabBindingSpecFluentImpl.AccessTokenNested<A> editAccessToken() {
    return withNewAccessTokenLike(getAccessToken());
  }
  public GitLabBindingSpecFluentImpl.AccessTokenNested<A> editOrNewAccessToken() {
    return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): new SecretValueFromSourceBuilder().build());
  }
  public GitLabBindingSpecFluentImpl.AccessTokenNested<A> editOrNewAccessTokenLike(SecretValueFromSource item) {
    return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSubject instead.
   * @return The buildable object.
   */
  @Deprecated
  public Reference getSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  public Reference buildSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  public A withSubject(Reference subject) {
    _visitables.get("subject").remove(this.subject);
    if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} else { this.subject = null; _visitables.get("subject").remove(this.subject); } return (A) this;
  }
  public Boolean hasSubject() {
    return this.subject != null;
  }
  public GitLabBindingSpecFluentImpl.SubjectNested<A> withNewSubject() {
    return new GitLabBindingSpecFluentImpl.SubjectNestedImpl();
  }
  public GitLabBindingSpecFluentImpl.SubjectNested<A> withNewSubjectLike(Reference item) {
    return new GitLabBindingSpecFluentImpl.SubjectNestedImpl(item);
  }
  public GitLabBindingSpecFluentImpl.SubjectNested<A> editSubject() {
    return withNewSubjectLike(getSubject());
  }
  public GitLabBindingSpecFluentImpl.SubjectNested<A> editOrNewSubject() {
    return withNewSubjectLike(getSubject() != null ? getSubject(): new ReferenceBuilder().build());
  }
  public GitLabBindingSpecFluentImpl.SubjectNested<A> editOrNewSubjectLike(Reference item) {
    return withNewSubjectLike(getSubject() != null ? getSubject(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitLabBindingSpecFluentImpl that = (GitLabBindingSpecFluentImpl) o;
    if (!java.util.Objects.equals(accessToken, that.accessToken)) return false;

    if (!java.util.Objects.equals(subject, that.subject)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accessToken,  subject,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accessToken != null) { sb.append("accessToken:"); sb.append(accessToken + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject); }
    sb.append("}");
    return sb.toString();
  }
  class AccessTokenNestedImpl<N> extends SecretValueFromSourceFluentImpl<GitLabBindingSpecFluentImpl.AccessTokenNested<N>> implements GitLabBindingSpecFluentImpl.AccessTokenNested<N>,Nested<N>{
    AccessTokenNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    AccessTokenNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) GitLabBindingSpecFluentImpl.this.withAccessToken(builder.build());
    }
    public N endAccessToken() {
      return and();
    }
    
  }
  class SubjectNestedImpl<N> extends ReferenceFluentImpl<GitLabBindingSpecFluentImpl.SubjectNested<N>> implements GitLabBindingSpecFluentImpl.SubjectNested<N>,Nested<N>{
    SubjectNestedImpl(Reference item) {
      this.builder = new ReferenceBuilder(this, item);
    }
    SubjectNestedImpl() {
      this.builder = new ReferenceBuilder(this);
    }
    ReferenceBuilder builder;
    public N and() {
      return (N) GitLabBindingSpecFluentImpl.this.withSubject(builder.build());
    }
    public N endSubject() {
      return and();
    }
    
  }
  
}
